Class: Google::Apis::TranslateV3beta1::DocumentOutputConfig
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3beta1::DocumentOutputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3beta1/classes.rb,
lib/google/apis/translate_v3beta1/representations.rb,
lib/google/apis/translate_v3beta1/representations.rb
Overview
A document translation request output config.
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::TranslateV3beta1::GcsDestination
The Google Cloud Storage location for the output content.
-
#mime_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DocumentOutputConfig
constructor
A new instance of DocumentOutputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DocumentOutputConfig
Returns a new instance of DocumentOutputConfig.
406 407 408 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::TranslateV3beta1::GcsDestination
The Google Cloud Storage location for the output content.
Corresponds to the JSON property gcsDestination
393 394 395 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 393 def gcs_destination @gcs_destination end |
#mime_type ⇒ String
Optional. Specifies the translated document's mime_type. If not specified, the translated file's mime type will be the same as the input file's mime type. Currently only support the output mime type to be the same as input mime type.
- application/pdf - application/vnd.openxmlformats-officedocument.
wordprocessingml.document - application/vnd.openxmlformats-officedocument.
presentationml.presentation - application/vnd.openxmlformats-officedocument.
spreadsheetml.sheet
Corresponds to the JSON property
mimeType
404 405 406 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 404 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
411 412 413 414 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 411 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @mime_type = args[:mime_type] if args.key?(:mime_type) end |