Class: Google::Apis::TranslateV3beta1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/translate_v3beta1/classes.rb,
lib/google/apis/translate_v3beta1/representations.rb,
lib/google/apis/translate_v3beta1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



734
735
736
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


719
720
721
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 719

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::TranslateV3beta1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



724
725
726
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 724

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


732
733
734
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 732

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



739
740
741
742
743
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 739

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end