Class: Google::Apis::TranslateV3beta1::TranslateDocumentRequest
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3beta1::TranslateDocumentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3beta1/classes.rb,
lib/google/apis/translate_v3beta1/representations.rb,
lib/google/apis/translate_v3beta1/representations.rb
Overview
A document translation request.
Instance Attribute Summary collapse
-
#customized_attribution ⇒ String
Optional.
-
#document_input_config ⇒ Google::Apis::TranslateV3beta1::DocumentInputConfig
A document translation request input config.
-
#document_output_config ⇒ Google::Apis::TranslateV3beta1::DocumentOutputConfig
A document translation request output config.
-
#enable_rotation_correction ⇒ Boolean
(also: #enable_rotation_correction?)
Optional.
-
#enable_shadow_removal_native_pdf ⇒ Boolean
(also: #enable_shadow_removal_native_pdf?)
Optional.
-
#glossary_config ⇒ Google::Apis::TranslateV3beta1::TranslateTextGlossaryConfig
Configures which glossary should be used for a specific target language, and defines options for applying that glossary.
-
#is_translate_native_pdf_only ⇒ Boolean
(also: #is_translate_native_pdf_only?)
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#model ⇒ String
Optional.
-
#source_language_code ⇒ String
Optional.
-
#target_language_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TranslateDocumentRequest
constructor
A new instance of TranslateDocumentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TranslateDocumentRequest
Returns a new instance of TranslateDocumentRequest.
1141 1142 1143 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customized_attribution ⇒ String
Optional. This flag is to support user customized attribution. If not provided,
the default is Machine Translated by Google. Customized attribution should
follow rules in https://cloud.google.com/translate/attribution#
attribution_and_logos
Corresponds to the JSON property customizedAttribution
1064 1065 1066 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1064 def customized_attribution @customized_attribution end |
#document_input_config ⇒ Google::Apis::TranslateV3beta1::DocumentInputConfig
A document translation request input config.
Corresponds to the JSON property documentInputConfig
1069 1070 1071 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1069 def document_input_config @document_input_config end |
#document_output_config ⇒ Google::Apis::TranslateV3beta1::DocumentOutputConfig
A document translation request output config.
Corresponds to the JSON property documentOutputConfig
1074 1075 1076 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1074 def document_output_config @document_output_config end |
#enable_rotation_correction ⇒ Boolean Also known as: enable_rotation_correction?
Optional. If true, enable auto rotation correction in DVS.
Corresponds to the JSON property enableRotationCorrection
1079 1080 1081 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1079 def enable_rotation_correction @enable_rotation_correction end |
#enable_shadow_removal_native_pdf ⇒ Boolean Also known as: enable_shadow_removal_native_pdf?
Optional. If true, use the text removal server to remove the shadow text on
background image for native pdf translation. Shadow removal feature can only
be enabled when is_translate_native_pdf_only: false && pdf_native_only: false
Corresponds to the JSON property enableShadowRemovalNativePdf
1087 1088 1089 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1087 def enable_shadow_removal_native_pdf @enable_shadow_removal_native_pdf end |
#glossary_config ⇒ Google::Apis::TranslateV3beta1::TranslateTextGlossaryConfig
Configures which glossary should be used for a specific target language, and
defines options for applying that glossary.
Corresponds to the JSON property glossaryConfig
1094 1095 1096 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1094 def glossary_config @glossary_config end |
#is_translate_native_pdf_only ⇒ Boolean Also known as: is_translate_native_pdf_only?
Optional. is_translate_native_pdf_only field for external customers. If true,
the page limit of online native pdf translation is 300 and only native pdf
pages will be translated.
Corresponds to the JSON property isTranslateNativePdfOnly
1101 1102 1103 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1101 def is_translate_native_pdf_only @is_translate_native_pdf_only end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. Label keys
and values can be no longer than 63 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter. See https://cloud.google.com/translate/docs/advanced/
labels for more information.
Corresponds to the JSON property labels
1112 1113 1114 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1112 def labels @labels end |
#model ⇒ String
Optional. The model type requested for this translation. The format depends
on model type: - AutoML Translation models: projects/project-number-or-id/
locations/location-id/models/model-id`- General (built-in) models:
projects/project-number-or-id/locations/location-id/models/general/nmt,
If not provided, the default Google model (NMT) will be used for translation.
Corresponds to the JSON propertymodel`
1121 1122 1123 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1121 def model @model end |
#source_language_code ⇒ String
Optional. The BCP-47 language code of the input document if known, for example,
"en-US" or "sr-Latn". Supported language codes are listed in Language
Support. If the source
language isn't specified, the API attempts to identify the source language
automatically and returns the source language within the response. Source
language must be specified if the request contains a glossary or a custom
model.
Corresponds to the JSON property sourceLanguageCode
1132 1133 1134 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1132 def source_language_code @source_language_code end |
#target_language_code ⇒ String
Required. The BCP-47 language code to use for translation of the input
document, set to one of the language codes listed in Language Support.
Corresponds to the JSON property targetLanguageCode
1139 1140 1141 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1139 def target_language_code @target_language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1146 def update!(**args) @customized_attribution = args[:customized_attribution] if args.key?(:customized_attribution) @document_input_config = args[:document_input_config] if args.key?(:document_input_config) @document_output_config = args[:document_output_config] if args.key?(:document_output_config) @enable_rotation_correction = args[:enable_rotation_correction] if args.key?(:enable_rotation_correction) @enable_shadow_removal_native_pdf = args[:enable_shadow_removal_native_pdf] if args.key?(:enable_shadow_removal_native_pdf) @glossary_config = args[:glossary_config] if args.key?(:glossary_config) @is_translate_native_pdf_only = args[:is_translate_native_pdf_only] if args.key?(:is_translate_native_pdf_only) @labels = args[:labels] if args.key?(:labels) @model = args[:model] if args.key?(:model) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) @target_language_code = args[:target_language_code] if args.key?(:target_language_code) end |