Class: Google::Apis::TranslateV3beta1::TranslateTextResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/translate_v3beta1/classes.rb,
lib/google/apis/translate_v3beta1/representations.rb,
lib/google/apis/translate_v3beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TranslateTextResponse

Returns a new instance of TranslateTextResponse.



1332
1333
1334
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#glossary_translationsArray<Google::Apis::TranslateV3beta1::Translation>

Text translation responses if a glossary is provided in the request. This can be the same as translations if no terms apply. This field has the same length as contents. Corresponds to the JSON property glossaryTranslations



1324
1325
1326
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1324

def glossary_translations
  @glossary_translations
end

#translationsArray<Google::Apis::TranslateV3beta1::Translation>

Text translation responses with no glossary applied. This field has the same length as contents. Corresponds to the JSON property translations



1330
1331
1332
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1330

def translations
  @translations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1337
1338
1339
1340
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 1337

def update!(**args)
  @glossary_translations = args[:glossary_translations] if args.key?(:glossary_translations)
  @translations = args[:translations] if args.key?(:translations)
end