Class: Google::Apis::TranslateV3beta1::BatchTranslateTextRequest
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3beta1::BatchTranslateTextRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3beta1/classes.rb,
lib/google/apis/translate_v3beta1/representations.rb,
lib/google/apis/translate_v3beta1/representations.rb
Overview
The batch translation request.
Instance Attribute Summary collapse
-
#glossaries ⇒ Hash<String,Google::Apis::TranslateV3beta1::TranslateTextGlossaryConfig>
Optional.
-
#input_configs ⇒ Array<Google::Apis::TranslateV3beta1::InputConfig>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#models ⇒ Hash<String,String>
Optional.
-
#output_config ⇒ Google::Apis::TranslateV3beta1::OutputConfig
Output configuration for BatchTranslateText request.
-
#source_language_code ⇒ String
Required.
-
#target_language_codes ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchTranslateTextRequest
constructor
A new instance of BatchTranslateTextRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchTranslateTextRequest
Returns a new instance of BatchTranslateTextRequest.
226 227 228 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#glossaries ⇒ Hash<String,Google::Apis::TranslateV3beta1::TranslateTextGlossaryConfig>
Optional. Glossaries to be applied for translation. It's keyed by target
language code.
Corresponds to the JSON property glossaries
177 178 179 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 177 def glossaries @glossaries end |
#input_configs ⇒ Array<Google::Apis::TranslateV3beta1::InputConfig>
Required. Input configurations. The total number of files matched should be <=
- The total content size should be <= 100M Unicode codepoints. The files
must use UTF-8 encoding.
Corresponds to the JSON property
inputConfigs
184 185 186 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 184 def input_configs @input_configs end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. Label keys
and values can be no longer than 63 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter. See https://cloud.google.com/translate/docs/labels
for more information.
Corresponds to the JSON property labels
194 195 196 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 194 def labels @labels end |
#models ⇒ Hash<String,String>
Optional. The models to use for translation. Map's key is target language code.
Map's value is model name. Value can be a built-in general model, or an
AutoML Translation model. The value format depends on model type: - AutoML
Translation models: projects/project-number-or-id/locations/location-id/
models/model-id`- General (built-in) models:projects/project-number-or-
id/locations/location-id/models/general/nmt, If the map is empty or a
specific model is not requested for a language pair, then default google model
(nmt) is used.
Corresponds to the JSON propertymodels`
206 207 208 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 206 def models @models end |
#output_config ⇒ Google::Apis::TranslateV3beta1::OutputConfig
Output configuration for BatchTranslateText request.
Corresponds to the JSON property outputConfig
211 212 213 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 211 def output_config @output_config end |
#source_language_code ⇒ String
Required. Source language code. Supported language codes are listed in
Language Support.
Corresponds to the JSON property sourceLanguageCode
217 218 219 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 217 def source_language_code @source_language_code end |
#target_language_codes ⇒ Array<String>
Required. Specify up to 10 language codes here. Supported language codes are
listed in Language Support
.
Corresponds to the JSON property targetLanguageCodes
224 225 226 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 224 def target_language_codes @target_language_codes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
231 232 233 234 235 236 237 238 239 |
# File 'lib/google/apis/translate_v3beta1/classes.rb', line 231 def update!(**args) @glossaries = args[:glossaries] if args.key?(:glossaries) @input_configs = args[:input_configs] if args.key?(:input_configs) @labels = args[:labels] if args.key?(:labels) @models = args[:models] if args.key?(:models) @output_config = args[:output_config] if args.key?(:output_config) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) @target_language_codes = args[:target_language_codes] if args.key?(:target_language_codes) end |