Class: Google::Apis::TranslateV3beta1::TranslateService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::TranslateV3beta1::TranslateService
- Defined in:
- lib/google/apis/translate_v3beta1/service.rb
Overview
Cloud Translation API
Integrates text translation into your website or application.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://translation.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#batch_location_translate_document(parent, batch_translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Translates a large volume of document in asynchronous batch mode.
-
#batch_location_translate_text(parent, batch_translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Translates a large volume of text in asynchronous batch mode.
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_glossary(parent, glossary_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Creates a glossary and returns the long-running operation.
-
#delete_project_location_glossary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Deletes a glossary, or cancels glossary construction if the glossary isn't created yet.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Empty
Deletes a long-running operation.
-
#detect_location_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::DetectLanguageResponse
Detects the language of text within a request.
-
#detect_project_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::DetectLanguageResponse
Detects the language of text within a request.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Location
Gets information about a location.
-
#get_project_location_glossary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Glossary
Gets a glossary.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::SupportedLanguages
Returns a list of supported languages for translation.
-
#get_project_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::SupportedLanguages
Returns a list of supported languages for translation.
-
#initialize ⇒ TranslateService
constructor
A new instance of TranslateService.
-
#list_project_location_glossaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListGlossariesResponse
Lists glossaries in a project.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#refine_location_text(parent, refine_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::RefineTextResponse
Refines the input translated text to improve the quality.
-
#translate_location_document(parent, translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateDocumentResponse
Translates documents in synchronous mode.
-
#translate_location_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateTextResponse
Translates input text and returns translated text.
-
#translate_project_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateTextResponse
Translates input text and returns translated text.
-
#wait_operation(name, wait_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state.
Constructor Details
#initialize ⇒ TranslateService
Returns a new instance of TranslateService.
47 48 49 50 51 52 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-translate_v3beta1', client_version: Google::Apis::TranslateV3beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#batch_location_translate_document(parent, batch_translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Translates a large volume of document in asynchronous batch mode. This function provides real-time output as the inputs are being processed. If caller cancels a request, the partial results (for an input file, it's all or nothing) may still be available on the specified output location. This call returns immediately and you can use google.longrunning.Operation.name to poll the status of the call.
210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 210 def batch_location_translate_document(parent, batch_translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:batchTranslateDocument', ) command.request_representation = Google::Apis::TranslateV3beta1::BatchTranslateDocumentRequest::Representation command.request_object = batch_translate_document_request_object command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation command.response_class = Google::Apis::TranslateV3beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#batch_location_translate_text(parent, batch_translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Translates a large volume of text in asynchronous batch mode. This function provides real-time output as the inputs are being processed. If caller cancels a request, the partial results (for an input file, it's all or nothing) may still be available on the specified output location. This call returns immediately and you can use google.longrunning.Operation.name to poll the status of the call.
252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 252 def batch_location_translate_text(parent, batch_translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:batchTranslateText', ) command.request_representation = Google::Apis::TranslateV3beta1::BatchTranslateTextRequest::Representation command.request_object = batch_translate_text_request_object command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation command.response_class = Google::Apis::TranslateV3beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
729 730 731 732 733 734 735 736 737 738 739 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 729 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+name}:cancel', ) command.request_representation = Google::Apis::TranslateV3beta1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::TranslateV3beta1::Empty::Representation command.response_class = Google::Apis::TranslateV3beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_glossary(parent, glossary_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Creates a glossary and returns the long-running operation. Returns NOT_FOUND, if the project doesn't exist.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 572 def create_project_location_glossary(parent, glossary_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}/glossaries', ) command.request_representation = Google::Apis::TranslateV3beta1::Glossary::Representation command.request_object = glossary_object command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation command.response_class = Google::Apis::TranslateV3beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_glossary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Deletes a glossary, or cancels glossary construction if the glossary isn't created yet. Returns NOT_FOUND, if the glossary doesn't exist.
605 606 607 608 609 610 611 612 613 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 605 def delete_project_location_glossary(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v3beta1/{+name}', ) command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation command.response_class = Google::Apis::TranslateV3beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
764 765 766 767 768 769 770 771 772 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 764 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v3beta1/{+name}', ) command.response_representation = Google::Apis::TranslateV3beta1::Empty::Representation command.response_class = Google::Apis::TranslateV3beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#detect_location_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::DetectLanguageResponse
Detects the language of text within a request.
290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 290 def detect_location_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:detectLanguage', ) command.request_representation = Google::Apis::TranslateV3beta1::DetectLanguageRequest::Representation command.request_object = detect_language_request_object command.response_representation = Google::Apis::TranslateV3beta1::DetectLanguageResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::DetectLanguageResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#detect_project_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::DetectLanguageResponse
Detects the language of text within a request.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 80 def detect_project_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:detectLanguage', ) command.request_representation = Google::Apis::TranslateV3beta1::DetectLanguageRequest::Representation command.request_object = detect_language_request_object command.response_representation = Google::Apis::TranslateV3beta1::DetectLanguageResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::DetectLanguageResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Location
Gets information about a location.
322 323 324 325 326 327 328 329 330 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 322 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+name}', ) command.response_representation = Google::Apis::TranslateV3beta1::Location::Representation command.response_class = Google::Apis::TranslateV3beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_glossary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Glossary
Gets a glossary. Returns NOT_FOUND, if the glossary doesn't exist.
635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 635 def get_project_location_glossary(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+name}', ) command.response_representation = Google::Apis::TranslateV3beta1::Glossary::Representation command.response_class = Google::Apis::TranslateV3beta1::Glossary command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
795 796 797 798 799 800 801 802 803 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 795 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+name}', ) command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation command.response_class = Google::Apis::TranslateV3beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::SupportedLanguages
Returns a list of supported languages for translation.
369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 369 def get_project_location_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+parent}/supportedLanguages', ) command.response_representation = Google::Apis::TranslateV3beta1::SupportedLanguages::Representation command.response_class = Google::Apis::TranslateV3beta1::SupportedLanguages command.params['parent'] = parent unless parent.nil? command.query['displayLanguageCode'] = display_language_code unless display_language_code.nil? command.query['model'] = model unless model.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::SupportedLanguages
Returns a list of supported languages for translation.
129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 129 def get_project_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+parent}/supportedLanguages', ) command.response_representation = Google::Apis::TranslateV3beta1::SupportedLanguages::Representation command.response_class = Google::Apis::TranslateV3beta1::SupportedLanguages command.params['parent'] = parent unless parent.nil? command.query['displayLanguageCode'] = display_language_code unless display_language_code.nil? command.query['model'] = model unless model.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_glossaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListGlossariesResponse
Lists glossaries in a project. Returns NOT_FOUND, if the project doesn't exist.
688 689 690 691 692 693 694 695 696 697 698 699 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 688 def list_project_location_glossaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+parent}/glossaries', ) command.response_representation = Google::Apis::TranslateV3beta1::ListGlossariesResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::ListGlossariesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
840 841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 840 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+name}/operations', ) command.response_representation = Google::Apis::TranslateV3beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 423 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3beta1/{+name}/locations', ) command.response_representation = Google::Apis::TranslateV3beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#refine_location_text(parent, refine_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::RefineTextResponse
Refines the input translated text to improve the quality.
461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 461 def refine_location_text(parent, refine_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:refineText', ) command.request_representation = Google::Apis::TranslateV3beta1::RefineTextRequest::Representation command.request_object = refine_text_request_object command.response_representation = Google::Apis::TranslateV3beta1::RefineTextResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::RefineTextResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#translate_location_document(parent, translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateDocumentResponse
Translates documents in synchronous mode.
499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 499 def translate_location_document(parent, translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:translateDocument', ) command.request_representation = Google::Apis::TranslateV3beta1::TranslateDocumentRequest::Representation command.request_object = translate_document_request_object command.response_representation = Google::Apis::TranslateV3beta1::TranslateDocumentResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::TranslateDocumentResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#translate_location_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateTextResponse
Translates input text and returns translated text.
538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 538 def translate_location_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:translateText', ) command.request_representation = Google::Apis::TranslateV3beta1::TranslateTextRequest::Representation command.request_object = translate_text_request_object command.response_representation = Google::Apis::TranslateV3beta1::TranslateTextResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::TranslateTextResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#translate_project_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateTextResponse
Translates input text and returns translated text.
168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 168 def translate_project_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+parent}:translateText', ) command.request_representation = Google::Apis::TranslateV3beta1::TranslateTextRequest::Representation command.request_object = translate_text_request_object command.response_representation = Google::Apis::TranslateV3beta1::TranslateTextResponse::Representation command.response_class = Google::Apis::TranslateV3beta1::TranslateTextResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#wait_operation(name, wait_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation
Waits until the specified long-running operation is done or reaches at most a
specified timeout, returning the latest state. If the operation is already
done, the latest state is immediately returned. If the timeout specified is
greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If
the server does not support this method, it returns google.rpc.Code.
UNIMPLEMENTED. Note that this method is on a best-effort basis. It may return
the latest state before the specified timeout (including immediately), meaning
even an immediate response is no guarantee that the operation is done.
882 883 884 885 886 887 888 889 890 891 892 |
# File 'lib/google/apis/translate_v3beta1/service.rb', line 882 def wait_operation(name, wait_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3beta1/{+name}:wait', ) command.request_representation = Google::Apis::TranslateV3beta1::WaitOperationRequest::Representation command.request_object = wait_operation_request_object command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation command.response_class = Google::Apis::TranslateV3beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |