Class: Google::Apis::TranslateV3beta1::TranslateService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/translate_v3beta1/service.rb

Overview

Cloud Translation API

Integrates text translation into your website or application.

Examples:

require 'google/apis/translate_v3beta1'

Translate = Google::Apis::TranslateV3beta1 # Alias the module
service = Translate::TranslateService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://translation.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeTranslateService

Returns a new instance of TranslateService.



47
48
49
50
51
52
# File 'lib/google/apis/translate_v3beta1/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-translate_v3beta1',
        client_version: Google::Apis::TranslateV3beta1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/translate_v3beta1/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/translate_v3beta1/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#batch_location_translate_document(parent, batch_translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation

Translates a large volume of document in asynchronous batch mode. This function provides real-time output as the inputs are being processed. If caller cancels a request, the partial results (for an input file, it's all or nothing) may still be available on the specified output location. This call returns immediately and you can use google.longrunning.Operation.name to poll the status of the call.

Parameters:

  • parent (String)

    Required. Location to make a regional call. Format: projects/project-number- or-id/locations/location-id`. Theglobal` location is not supported for batch translation. Only AutoML Translation models or glossaries within the same region (have the same location-id) can be used, otherwise an INVALID_ARGUMENT (400) error is returned.

  • batch_translate_document_request_object (Google::Apis::TranslateV3beta1::BatchTranslateDocumentRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



210
211
212
213
214
215
216
217
218
219
220
# File 'lib/google/apis/translate_v3beta1/service.rb', line 210

def batch_location_translate_document(parent, batch_translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:batchTranslateDocument', options)
  command.request_representation = Google::Apis::TranslateV3beta1::BatchTranslateDocumentRequest::Representation
  command.request_object = batch_translate_document_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#batch_location_translate_text(parent, batch_translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation

Translates a large volume of text in asynchronous batch mode. This function provides real-time output as the inputs are being processed. If caller cancels a request, the partial results (for an input file, it's all or nothing) may still be available on the specified output location. This call returns immediately and you can use google.longrunning.Operation.name to poll the status of the call.

Parameters:

  • parent (String)

    Required. Location to make a call. Must refer to a caller's project. Format: projects/project-number-or-id/locations/location-id`. Theglobal` location is not supported for batch translation. Only AutoML Translation models or glossaries within the same region (have the same location-id) can be used, otherwise an INVALID_ARGUMENT (400) error is returned.

  • batch_translate_text_request_object (Google::Apis::TranslateV3beta1::BatchTranslateTextRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



252
253
254
255
256
257
258
259
260
261
262
# File 'lib/google/apis/translate_v3beta1/service.rb', line 252

def batch_location_translate_text(parent, batch_translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:batchTranslateText', options)
  command.request_representation = Google::Apis::TranslateV3beta1::BatchTranslateTextRequest::Representation
  command.request_object = batch_translate_text_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Empty

Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1 , corresponding to Code.CANCELLED.

Parameters:

  • name (String)

    The name of the operation resource to be cancelled.

  • cancel_operation_request_object (Google::Apis::TranslateV3beta1::CancelOperationRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



724
725
726
727
728
729
730
731
732
733
734
# File 'lib/google/apis/translate_v3beta1/service.rb', line 724

def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+name}:cancel', options)
  command.request_representation = Google::Apis::TranslateV3beta1::CancelOperationRequest::Representation
  command.request_object = cancel_operation_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::Empty::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_project_location_glossary(parent, glossary_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation

Creates a glossary and returns the long-running operation. Returns NOT_FOUND, if the project doesn't exist.

Parameters:

  • parent (String)

    Required. The project name.

  • glossary_object (Google::Apis::TranslateV3beta1::Glossary) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



567
568
569
570
571
572
573
574
575
576
577
# File 'lib/google/apis/translate_v3beta1/service.rb', line 567

def create_project_location_glossary(parent, glossary_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}/glossaries', options)
  command.request_representation = Google::Apis::TranslateV3beta1::Glossary::Representation
  command.request_object = glossary_object
  command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_location_glossary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation

Deletes a glossary, or cancels glossary construction if the glossary isn't created yet. Returns NOT_FOUND, if the glossary doesn't exist.

Parameters:

  • name (String)

    Required. The name of the glossary to delete.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



600
601
602
603
604
605
606
607
608
# File 'lib/google/apis/translate_v3beta1/service.rb', line 600

def delete_project_location_glossary(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v3beta1/{+name}', options)
  command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Empty

Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns google.rpc.Code. UNIMPLEMENTED.

Parameters:

  • name (String)

    The name of the operation resource to be deleted.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



759
760
761
762
763
764
765
766
767
# File 'lib/google/apis/translate_v3beta1/service.rb', line 759

def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v3beta1/{+name}', options)
  command.response_representation = Google::Apis::TranslateV3beta1::Empty::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#detect_location_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::DetectLanguageResponse

Detects the language of text within a request.

Parameters:

  • parent (String)

    Required. Project or location to make a call. Must refer to a caller's project. Format: projects/project-number-or-id/locations/location-idor ` projects/`project-number-or-id. For global calls, use projects/project- number-or-id/locations/global or projects/project-number-or-id``. Only models within the same region (has same location-id) can be used. Otherwise an INVALID_ARGUMENT (400) error is returned.

  • detect_language_request_object (Google::Apis::TranslateV3beta1::DetectLanguageRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



290
291
292
293
294
295
296
297
298
299
300
# File 'lib/google/apis/translate_v3beta1/service.rb', line 290

def detect_location_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:detectLanguage', options)
  command.request_representation = Google::Apis::TranslateV3beta1::DetectLanguageRequest::Representation
  command.request_object = detect_language_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::DetectLanguageResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::DetectLanguageResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#detect_project_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::DetectLanguageResponse

Detects the language of text within a request.

Parameters:

  • parent (String)

    Required. Project or location to make a call. Must refer to a caller's project. Format: projects/project-number-or-id/locations/location-idor ` projects/`project-number-or-id. For global calls, use projects/project- number-or-id/locations/global or projects/project-number-or-id``. Only models within the same region (has same location-id) can be used. Otherwise an INVALID_ARGUMENT (400) error is returned.

  • detect_language_request_object (Google::Apis::TranslateV3beta1::DetectLanguageRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/google/apis/translate_v3beta1/service.rb', line 80

def detect_project_language(parent, detect_language_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:detectLanguage', options)
  command.request_representation = Google::Apis::TranslateV3beta1::DetectLanguageRequest::Representation
  command.request_object = detect_language_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::DetectLanguageResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::DetectLanguageResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Location

Gets information about a location.

Parameters:

  • name (String)

    Resource name for the location.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



322
323
324
325
326
327
328
329
330
# File 'lib/google/apis/translate_v3beta1/service.rb', line 322

def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+name}', options)
  command.response_representation = Google::Apis::TranslateV3beta1::Location::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Location
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_glossary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Glossary

Gets a glossary. Returns NOT_FOUND, if the glossary doesn't exist.

Parameters:

  • name (String)

    Required. The name of the glossary to retrieve.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



630
631
632
633
634
635
636
637
638
# File 'lib/google/apis/translate_v3beta1/service.rb', line 630

def get_project_location_glossary(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+name}', options)
  command.response_representation = Google::Apis::TranslateV3beta1::Glossary::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Glossary
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation

Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Parameters:

  • name (String)

    The name of the operation resource.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



790
791
792
793
794
795
796
797
798
# File 'lib/google/apis/translate_v3beta1/service.rb', line 790

def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+name}', options)
  command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::SupportedLanguages

Returns a list of supported languages for translation.

Parameters:

  • parent (String)

    Required. Project or location to make a call. Must refer to a caller's project. Format: projects/project-number-or-idor `projects/`project-number-or-id`/ locations/`location-id. For global calls, use projects/project-number-or- id/locations/global or projects/project-number-or-id``. Non-global location is required for AutoML models. Only models within the same region ( have same location-id) can be used, otherwise an INVALID_ARGUMENT (400) error is returned.

  • display_language_code (String) (defaults to: nil)

    Optional. The language to use to return localized, human readable names of supported languages. If missing, then display names are not returned in a response.

  • model (String) (defaults to: nil)

    Optional. Get supported languages of this model. The format depends on model type: - AutoML Translation models: projects/project-number-or-id/locations/ location-id/models/model-id`- General (built-in) models:projects/ project-number-or-id/locations/location-id/models/general/nmt`, Returns languages supported by the specified model. If missing, we get supported languages of Google general NMT model.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/google/apis/translate_v3beta1/service.rb', line 369

def get_project_location_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+parent}/supportedLanguages', options)
  command.response_representation = Google::Apis::TranslateV3beta1::SupportedLanguages::Representation
  command.response_class = Google::Apis::TranslateV3beta1::SupportedLanguages
  command.params['parent'] = parent unless parent.nil?
  command.query['displayLanguageCode'] = display_language_code unless display_language_code.nil?
  command.query['model'] = model unless model.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::SupportedLanguages

Returns a list of supported languages for translation.

Parameters:

  • parent (String)

    Required. Project or location to make a call. Must refer to a caller's project. Format: projects/project-number-or-idor `projects/`project-number-or-id`/ locations/`location-id. For global calls, use projects/project-number-or- id/locations/global or projects/project-number-or-id``. Non-global location is required for AutoML models. Only models within the same region ( have same location-id) can be used, otherwise an INVALID_ARGUMENT (400) error is returned.

  • display_language_code (String) (defaults to: nil)

    Optional. The language to use to return localized, human readable names of supported languages. If missing, then display names are not returned in a response.

  • model (String) (defaults to: nil)

    Optional. Get supported languages of this model. The format depends on model type: - AutoML Translation models: projects/project-number-or-id/locations/ location-id/models/model-id`- General (built-in) models:projects/ project-number-or-id/locations/location-id/models/general/nmt`, Returns languages supported by the specified model. If missing, we get supported languages of Google general NMT model.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



129
130
131
132
133
134
135
136
137
138
139
# File 'lib/google/apis/translate_v3beta1/service.rb', line 129

def get_project_supported_languages(parent, display_language_code: nil, model: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+parent}/supportedLanguages', options)
  command.response_representation = Google::Apis::TranslateV3beta1::SupportedLanguages::Representation
  command.response_class = Google::Apis::TranslateV3beta1::SupportedLanguages
  command.params['parent'] = parent unless parent.nil?
  command.query['displayLanguageCode'] = display_language_code unless display_language_code.nil?
  command.query['model'] = model unless model.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_glossaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListGlossariesResponse

Lists glossaries in a project. Returns NOT_FOUND, if the project doesn't exist.

Parameters:

  • parent (String)

    Required. The name of the project from which to list all of the glossaries.

  • filter (String) (defaults to: nil)

    Optional. Filter specifying constraints of a list operation. Specify the constraint by the format of "key=value", where key must be "src" or "tgt", and the value must be a valid language code. For multiple restrictions, concatenate them by "AND" (uppercase only), such as: "src=en-US AND tgt=zh-CN". Notice that the exact match is used here, which means using 'en-US' and 'en' can lead to different results, which depends on the language code you used when you create the glossary. For the unidirectional glossaries, the "src" and "tgt" add restrictions on the source and target language code separately. For the equivalent term set glossaries, the "src" and/or "tgt" add restrictions on the term set. For example: "src=en-US AND tgt=zh-CN" will only pick the unidirectional glossaries which exactly match the source language code as "en- US" and the target language code "zh-CN", but all equivalent term set glossaries which contain "en-US" and "zh-CN" in their language set will be picked. If missing, no filtering is performed.

  • page_size (Fixnum) (defaults to: nil)

    Optional. Requested page size. The server may return fewer glossaries than requested. If unspecified, the server picks an appropriate default.

  • page_token (String) (defaults to: nil)

    Optional. A token identifying a page of results the server should return. Typically, this is the value of [ListGlossariesResponse.next_page_token] returned from the previous call to ListGlossaries method. The first page is returned if page_tokenis empty or missing.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



683
684
685
686
687
688
689
690
691
692
693
694
# File 'lib/google/apis/translate_v3beta1/service.rb', line 683

def list_project_location_glossaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+parent}/glossaries', options)
  command.response_representation = Google::Apis::TranslateV3beta1::ListGlossariesResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::ListGlossariesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListOperationsResponse

Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.

Parameters:

  • name (String)

    The name of the operation's parent resource.

  • filter (String) (defaults to: nil)

    The standard list filter.

  • page_size (Fixnum) (defaults to: nil)

    The standard list page size.

  • page_token (String) (defaults to: nil)

    The standard list page token.

  • return_partial_success (Boolean) (defaults to: nil)

    When set to true, operations that are reachable are returned as normal, and those that are unreachable are returned in the ListOperationsResponse. unreachable field. This can only be true when reading across collections. For example, when parent is set to "projects/example/locations/-". This field is not supported by default and will result in an UNIMPLEMENTED error if set unless explicitly documented otherwise in service or product specific documentation.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



835
836
837
838
839
840
841
842
843
844
845
846
847
# File 'lib/google/apis/translate_v3beta1/service.rb', line 835

def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+name}/operations', options)
  command.response_representation = Google::Apis::TranslateV3beta1::ListOperationsResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::ListOperationsResponse
  command.params['name'] = name unless name.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::ListLocationsResponse

Lists information about the supported locations for this service. This method can be called in two ways: * List all public locations: Use the path GET / v1/locations. * List project-visible locations: Use the path GET /v1/ projects/project_id/locations. This may include public locations as well as private or other locations specifically visible to the project.

Parameters:

  • name (String)

    The resource that owns the locations collection, if applicable.

  • extra_location_types (Array<String>, String) (defaults to: nil)

    Optional. Do not use this field. It is unsupported and is ignored unless explicitly documented otherwise. This is primarily for internal usage.

  • filter (String) (defaults to: nil)

    A filter to narrow down results to a preferred subset. The filtering language accepts strings like "displayName=tokyo", and is documented in more detail in AIP-160.

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of results to return. If not set, the service selects a default.

  • page_token (String) (defaults to: nil)

    A page token received from the next_page_token field in the response. Send that page token to receive the subsequent page.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/google/apis/translate_v3beta1/service.rb', line 418

def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v3beta1/{+name}/locations', options)
  command.response_representation = Google::Apis::TranslateV3beta1::ListLocationsResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::ListLocationsResponse
  command.params['name'] = name unless name.nil?
  command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#refine_location_text(parent, refine_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::RefineTextResponse

Refines the input translated text to improve the quality.

Parameters:

  • parent (String)

    Required. Project or location to make a call. Must refer to a caller's project. Format: projects/project-number-or-id/locations/location-id. For global calls, use `projects/`project-number-or-id`/locations/global` or `projects/` project-number-or-id.

  • refine_text_request_object (Google::Apis::TranslateV3beta1::RefineTextRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



456
457
458
459
460
461
462
463
464
465
466
# File 'lib/google/apis/translate_v3beta1/service.rb', line 456

def refine_location_text(parent, refine_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:refineText', options)
  command.request_representation = Google::Apis::TranslateV3beta1::RefineTextRequest::Representation
  command.request_object = refine_text_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::RefineTextResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::RefineTextResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#translate_location_document(parent, translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateDocumentResponse

Translates documents in synchronous mode.

Parameters:

  • parent (String)

    Required. Location to make a regional call. Format: projects/project-number- or-id/locations/location-id`. For global calls, useprojects/project- number-or-id/locations/global`. Non-global location is required for requests using AutoML models or custom glossaries. Models and glossaries must be within the same region (have the same location-id), otherwise an INVALID_ARGUMENT ( 400) error is returned.

  • translate_document_request_object (Google::Apis::TranslateV3beta1::TranslateDocumentRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



494
495
496
497
498
499
500
501
502
503
504
# File 'lib/google/apis/translate_v3beta1/service.rb', line 494

def translate_location_document(parent, translate_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:translateDocument', options)
  command.request_representation = Google::Apis::TranslateV3beta1::TranslateDocumentRequest::Representation
  command.request_object = translate_document_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::TranslateDocumentResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::TranslateDocumentResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#translate_location_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateTextResponse

Translates input text and returns translated text.

Parameters:

  • parent (String)

    Required. Project or location to make a call. Must refer to a caller's project. Format: projects/project-number-or-idor `projects/`project-number-or-id`/ locations/`location-id. For global calls, use projects/project-number-or- id/locations/global or projects/project-number-or-id``. Non-global location is required for requests using AutoML models or custom glossaries. Models and glossaries must be within the same region (have same location-id), otherwise an INVALID_ARGUMENT (400) error is returned.

  • translate_text_request_object (Google::Apis::TranslateV3beta1::TranslateTextRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



533
534
535
536
537
538
539
540
541
542
543
# File 'lib/google/apis/translate_v3beta1/service.rb', line 533

def translate_location_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:translateText', options)
  command.request_representation = Google::Apis::TranslateV3beta1::TranslateTextRequest::Representation
  command.request_object = translate_text_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::TranslateTextResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::TranslateTextResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#translate_project_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::TranslateTextResponse

Translates input text and returns translated text.

Parameters:

  • parent (String)

    Required. Project or location to make a call. Must refer to a caller's project. Format: projects/project-number-or-idor `projects/`project-number-or-id`/ locations/`location-id. For global calls, use projects/project-number-or- id/locations/global or projects/project-number-or-id``. Non-global location is required for requests using AutoML models or custom glossaries. Models and glossaries must be within the same region (have same location-id), otherwise an INVALID_ARGUMENT (400) error is returned.

  • translate_text_request_object (Google::Apis::TranslateV3beta1::TranslateTextRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



168
169
170
171
172
173
174
175
176
177
178
# File 'lib/google/apis/translate_v3beta1/service.rb', line 168

def translate_project_text(parent, translate_text_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+parent}:translateText', options)
  command.request_representation = Google::Apis::TranslateV3beta1::TranslateTextRequest::Representation
  command.request_object = translate_text_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::TranslateTextResponse::Representation
  command.response_class = Google::Apis::TranslateV3beta1::TranslateTextResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#wait_operation(name, wait_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TranslateV3beta1::Operation

Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns google.rpc.Code. UNIMPLEMENTED. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.

Parameters:

  • name (String)

    The name of the operation resource to wait on.

  • wait_operation_request_object (Google::Apis::TranslateV3beta1::WaitOperationRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



877
878
879
880
881
882
883
884
885
886
887
# File 'lib/google/apis/translate_v3beta1/service.rb', line 877

def wait_operation(name, wait_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v3beta1/{+name}:wait', options)
  command.request_representation = Google::Apis::TranslateV3beta1::WaitOperationRequest::Representation
  command.request_object = wait_operation_request_object
  command.response_representation = Google::Apis::TranslateV3beta1::Operation::Representation
  command.response_class = Google::Apis::TranslateV3beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end